//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using LidorSystems.IntegralUI.Drawing;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   In this sample we will show you how to apply different colors to columns, items and subitems in ListView control.</p><br></br>";
            content += "<p>   At first select the number of different colors you want to use, then choose which object you want to change.</p><br></br>";
            content += "<p>   To return back to orginal appearance, click on the Reset button.</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr><td width=\"100%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/listview/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
                System.Diagnostics.Process.Start((e.Object as LinkLabel).Links[0].LinkData.ToString());
        }

        private void InitList()
        {
            this.listView1.SuspendUpdate();

            LidorSystems.IntegralUI.Lists.ListViewColumn column = null;
            for (int j = 0; j < 3; j++)
            {
                column = new LidorSystems.IntegralUI.Lists.ListViewColumn("Column " + j.ToString(), "Footer " + j.ToString());
                column.Width = 120;

                this.listView1.Columns.Add(column);
            }


            LidorSystems.IntegralUI.Lists.ListViewItem item = null;
            LidorSystems.IntegralUI.Lists.ListViewSubItem subItem = null;

            for (int i = 0; i < 100; i++)
            {
                item = new LidorSystems.IntegralUI.Lists.ListViewItem("Item " + i.ToString());

                for (int j = 0; j < this.listView1.Columns.Count; j++)
                {
                    subItem = new LidorSystems.IntegralUI.Lists.ListViewSubItem("Item " + i.ToString() + j.ToString());
                    item.SubItems.Add(subItem);
                }

                this.listView1.Items.Add(item);
            }

            this.listView1.ResumeUpdate();
        }
        #endregion

        #region Different Colors
        private void btnUpdate_Click(object sender, EventArgs e)
        {
            this.listView1.SuspendPaint();

            int modifier = (int)numColors.Value;

            if (rbColumns.Checked)
            {
                LidorSystems.IntegralUI.Lists.ListViewColumn column = null;
                for (int j = 0; j < this.listView1.Columns.Count; j++)
                {
                    column = (LidorSystems.IntegralUI.Lists.ListViewColumn)this.listView1.Columns[j];

                    // Make sure column uses its own color style settings
                    column.StyleFromParent = false;

                    column.NormalStyle.HeaderColor = GetColumnColor(j % modifier);
                    column.NormalStyle.HeaderBorderColor = column.NormalStyle.HeaderColor;
                    column.NormalStyle.HeaderTextColor = Color.White;

                    column.NormalStyle.FooterColor = CommonMethods.ChangeColor(column.NormalStyle.HeaderColor, 25, true);
                    column.NormalStyle.FooterFadeColor = column.NormalStyle.FooterColor;
                    column.NormalStyle.FooterTextColor = Color.White;
                }
            }
            else if (rbItems.Checked)
            {
                LidorSystems.IntegralUI.Lists.ListViewItem item = null;
                for (int i = 0; i < this.listView1.Items.Count; i++)
                {
                    item = this.listView1.Items[i];

                    // Make sure item uses its own color style settings
                    item.StyleFromParent = false;

                    item.NormalStyle.FillStyle = LidorSystems.IntegralUI.Style.FillStyle.Horizontal;
                    item.NormalStyle.BackColor = GetItemColor(i % modifier);

                    // Reset the appearance of subitems to default one
                    foreach (LidorSystems.IntegralUI.Lists.ListViewSubItem subItem in item.SubItems)
                        subItem.StyleFromParent = true;
                }
            }
            else if (rbSubItems.Checked)
            {
                LidorSystems.IntegralUI.Lists.ListViewItem item = null;
                LidorSystems.IntegralUI.Lists.ListViewSubItem subItem = null;

                int colorIndex = 0;
                for (int i = 0; i < this.listView1.CurrentList.Count; i++)
                {
                    item = (LidorSystems.IntegralUI.Lists.ListViewItem)this.listView1.CurrentList[i];
                    
                    // Reset the appearance of item to default one
                    item.StyleFromParent = true;

                    for (int j = 0; j < item.SubItems.Count; j++)
                    {
                        subItem = item.SubItems[j];

                        // Make sure subitem uses its own color style settings
                        subItem.StyleFromParent = false;

                        subItem.NormalStyle.FillStyle = LidorSystems.IntegralUI.Style.FillStyle.Horizontal;
                        subItem.NormalStyle.BackColor = GetItemColor(colorIndex % modifier);

                        colorIndex++;
                    }
                }
            }

            this.listView1.ResumePaint();
        }

        private Color GetColumnColor(int index)
        {
            switch (index)
            {
                case 0:
                    return Color.Red;
                
                case 1:
                    return Color.Green;

                case 2:
                    return Color.Blue;
            }

            return Color.Empty;
        }

        private Color GetItemColor(int index)
        {
            switch (index)
            {
                case 1:
                    return Color.LightGray;

                case 2:
                    return  Color.LightBlue;

                case 3:
                    return  Color.Pink;

                case 4:
                    return  Color.LightGreen;

                case 5:
                    return  Color.Yellow;

                case 6:
                    return  Color.Azure;

                case 7:
                    return  Color.Gold;

                case 8:
                    return  Color.LightSalmon;

                case 9:
                    return  Color.Violet;
            }

            return Color.Empty;
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            // Suspend the control from repainting its view
            this.listView1.SuspendPaint();

            // Reset the appearance of all objects to default ones
            foreach (LidorSystems.IntegralUI.Lists.ListViewColumn column in this.listView1.Columns)
                column.StyleFromParent = true;

            foreach (LidorSystems.IntegralUI.Lists.ListViewItem item in this.listView1.CurrentList)
            {
                item.StyleFromParent = true;
                foreach (LidorSystems.IntegralUI.Lists.ListViewSubItem subItem in item.SubItems)
                    subItem.StyleFromParent = true;
            }

            // Resume and invalidate the control view
            this.listView1.ResumePaint();
        }
        #endregion
    }
}