'                                                                  
' Copyright  2013 Lidor Systems.
' All Rights Reserved.
'
' This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
' either express or implied.                        
'

Imports LidorSystems.IntegralUI.Drawing

Public Class Form1

#Region "Initialization"
    Public Sub New()
        InitializeComponent()

        CreateLabelContent()

        InitList()
    End Sub

    Private Sub CreateLabelContent()
        Dim content As [String] = "<div style=""font:Verdana,9,r""><p>   In this sample we will show you how to apply different colors to columns, items and subitems in ListView control.</p><br></br>"
        content += "<p>   At first select the number of different colors you want to use, then choose which object you want to change.</p><br></br>"
        content += "<p>   To return back to orginal appearance, click on the Reset button.</p><br></br>"
        content += "<p><table width=""100%"" cellpadding=""5""><tr><td width=""100%"" style=""align:middleright;textcolor:DarkRed;hovertextcolor:Red""><a href=""www.lidorsystems.com/support/articles/winforms/listview/"">More Info ...</a></td></tr></table></p>"
        content += "</div>"

        Me.labelInfo.Content = content
    End Sub

    Private Sub labelInfo_ContentObjectClicked(ByVal sender As Object, ByVal e As LidorSystems.IntegralUI.ObjectClickEventArgs) Handles labelInfo.ContentObjectClicked
        If TypeOf e.[Object] Is LinkLabel Then
            System.Diagnostics.Process.Start(TryCast(e.[Object], LinkLabel).Links(0).LinkData.ToString())
        End If
    End Sub

    Private Sub InitList()
        Me.listView1.SuspendUpdate()

        Dim column As LidorSystems.IntegralUI.Lists.ListViewColumn = Nothing
        For j As Integer = 0 To 2
            column = New LidorSystems.IntegralUI.Lists.ListViewColumn("Column " & j.ToString(), "Footer " & j.ToString())
            column.Width = 120

            Me.listView1.Columns.Add(column)
        Next


        Dim item As LidorSystems.IntegralUI.Lists.ListViewItem = Nothing
        Dim subItem As LidorSystems.IntegralUI.Lists.ListViewSubItem = Nothing

        For i As Integer = 0 To 99
            item = New LidorSystems.IntegralUI.Lists.ListViewItem("Item " & i.ToString())

            For j As Integer = 0 To Me.listView1.Columns.Count - 1
                subItem = New LidorSystems.IntegralUI.Lists.ListViewSubItem("Item " & i.ToString() & j.ToString())
                item.SubItems.Add(subItem)
            Next

            Me.listView1.Items.Add(item)
        Next

        Me.listView1.ResumeUpdate()
    End Sub
#End Region

#Region "Different Colors"
    Private Sub btnUpdate_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnUpdate.Click
        Me.listView1.SuspendPaint()

        Dim modifier As Integer = CInt(numColors.Value)

        If rbColumns.Checked Then
            Dim column As LidorSystems.IntegralUI.Lists.ListViewColumn = Nothing
            For j As Integer = 0 To Me.listView1.Columns.Count - 1
                column = DirectCast(Me.listView1.Columns(j), LidorSystems.IntegralUI.Lists.ListViewColumn)

                ' Make sure column uses its own color style settings
                column.StyleFromParent = False

                column.NormalStyle.HeaderColor = GetColumnColor(j Mod modifier)
                column.NormalStyle.HeaderBorderColor = column.NormalStyle.HeaderColor
                column.NormalStyle.HeaderTextColor = Color.White

                column.NormalStyle.FooterColor = CommonMethods.ChangeColor(column.NormalStyle.HeaderColor, 25, True)
                column.NormalStyle.FooterFadeColor = column.NormalStyle.FooterColor
                column.NormalStyle.FooterTextColor = Color.White
            Next
        ElseIf rbItems.Checked Then
            Dim item As LidorSystems.IntegralUI.Lists.ListViewItem = Nothing
            For i As Integer = 0 To Me.listView1.Items.Count - 1
                item = Me.listView1.Items(i)

                ' Make sure item uses its own color style settings
                item.StyleFromParent = False

                item.NormalStyle.FillStyle = LidorSystems.IntegralUI.Style.FillStyle.Horizontal
                item.NormalStyle.BackColor = GetItemColor(i Mod modifier)

                ' Reset the appearance of subitems to default one
                For Each subItem As LidorSystems.IntegralUI.Lists.ListViewSubItem In item.SubItems
                    subItem.StyleFromParent = True
                Next
            Next
        ElseIf rbSubItems.Checked Then
            Dim item As LidorSystems.IntegralUI.Lists.ListViewItem = Nothing
            Dim subItem As LidorSystems.IntegralUI.Lists.ListViewSubItem = Nothing

            Dim colorIndex As Integer = 0
            For i As Integer = 0 To Me.listView1.CurrentList.Count - 1
                item = DirectCast(Me.listView1.CurrentList(i), LidorSystems.IntegralUI.Lists.ListViewItem)

                ' Reset the appearance of item to default one
                item.StyleFromParent = True

                For j As Integer = 0 To item.SubItems.Count - 1
                    subItem = item.SubItems(j)

                    ' Make sure subitem uses its own color style settings
                    subItem.StyleFromParent = False

                    subItem.NormalStyle.FillStyle = LidorSystems.IntegralUI.Style.FillStyle.Horizontal
                    subItem.NormalStyle.BackColor = GetItemColor(colorIndex Mod modifier)

                    colorIndex += 1
                Next
            Next
        End If

        Me.listView1.ResumePaint()
    End Sub

    Private Function GetColumnColor(ByVal index As Integer) As Color
        Select Case index
            Case 0
                Return Color.Red

            Case 1
                Return Color.Green

            Case 2
                Return Color.Blue
        End Select

        Return Color.Empty
    End Function

    Private Function GetItemColor(ByVal index As Integer) As Color
        Select Case index
            Case 1
                Return Color.LightGray

            Case 2
                Return Color.LightBlue

            Case 3
                Return Color.Pink

            Case 4
                Return Color.LightGreen

            Case 5
                Return Color.Yellow

            Case 6
                Return Color.Azure

            Case 7
                Return Color.Gold

            Case 8
                Return Color.LightSalmon

            Case 9
                Return Color.Violet
        End Select

        Return Color.Empty
    End Function

    Private Sub btnReset_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnReset.Click
        ' Suspend the control from repainting its view
        Me.listView1.SuspendPaint()

        ' Reset the appearance of all objects to default ones
        For Each column As LidorSystems.IntegralUI.Lists.ListViewColumn In Me.listView1.Columns
            column.StyleFromParent = True
        Next

        For Each item As LidorSystems.IntegralUI.Lists.ListViewItem In Me.listView1.CurrentList
            item.StyleFromParent = True
            For Each subItem As LidorSystems.IntegralUI.Lists.ListViewSubItem In item.SubItems
                subItem.StyleFromParent = True
            Next
        Next

        ' Resume and invalidate the control view
        Me.listView1.ResumePaint()
    End Sub
#End Region

End Class
